/*
 * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
 *
 * Squid software is distributed under GPLv2+ license and includes
 * contributions from numerous individuals and organizations.
 * Please see the COPYING and CONTRIBUTORS files for details.
 */

#ifndef SQUID_COMPAT_OS_QNX_H
#define SQUID_COMPAT_OS_QNX_H

#if _SQUID_QNX_

/****************************************************************************
 *--------------------------------------------------------------------------*
 * DO *NOT* MAKE ANY CHANGES below here unless you know what you're doing...*
 *--------------------------------------------------------------------------*
 ****************************************************************************/

/*
 * Requires unix.h header file
 */
#include <unix.h>

#endif /* _SQUID_QNX_ */
#endif /* SQUID_COMPAT_OS_QNX_H */

